// ============================================================================
// ==                                                                        ==
// == AMDiS - Adaptive multidimensional simulations                          ==
// ==                                                                        ==
// ==  http://www.amdis-fem.org                                              ==
// ==                                                                        ==
// ============================================================================
//
// Software License for AMDiS
//
// Copyright (c) 2010 Dresden University of Technology 
// All rights reserved.
// Authors: Simon Vey, Thomas Witkowski et al.
//
// This file is part of AMDiS
//
// See also license.opensource.txt in the distribution.



/** \file ProblemInterpolScal.h */

#ifndef AMDIS_PROBLEMINTERPOLSCAL_H
#define AMDIS_PROBLEMINTERPOLSCAL_H

#include "AMDiS_fwd.h"
#include "ProblemScal.h"

namespace AMDiS {

  /// Interpolates a given function adaptive on spaceProblems mesh.
  class ProblemInterpolScal : public ProblemScal
  {
  public:
    /** \brief
     * Constructor. fct will be interpolated on the mesh of spaceProblem.
     * grdFct is used, if H1 error should be used for estimation. It points
     * to the gradient of fct.
     */
    ProblemInterpolScal(const char *name_,
			ProblemScal *spaceProblem,
			AbstractFunction<double, WorldVector<double> > *fct,
			AbstractFunction<WorldVector<double>, WorldVector<double> > *grdFct);

    /// No system assemblage.
    virtual void buildbeforeRefine(AdaptInfo *adaptInfo, Flag) {}

    /// No system assemblage.
    virtual void buildbeforeCoarsen(AdaptInfo *adaptInfo, Flag) {}

    /// No system assemblage.
    virtual void buildAfterCoarsen(AdaptInfo *adaptInfo, Flag) {}

    /// No equation system ins solved. Instead fct is interpolated to uh.
    virtual void solve(AdaptInfo *adaptInfo);

    /// True H1 or L2 error is calculated.
    virtual void estimate(AdaptInfo *adaptInfo, double);

  protected:
    /// Function to interpolate.
    AbstractFunction<double, WorldVector<double> > *interpolFct;

    /// Gradient of \ref interpolFct_. Used for H1 error in estimate().
    AbstractFunction<WorldVector<double>, WorldVector<double> > *grdInterpolFct;
  };

}

#endif
